@@ -5,7 +5,7 @@ package HTML::Mason;
 
 use 5.006;
 
-$HTML::Mason::VERSION = '1.44';
+$HTML::Mason::VERSION = '1.46';
 
 use HTML::Mason::Interp;
 
@@ -87,6 +87,21 @@ of Perl code (say, to pull records from a database). They can also
 call other components, cache results for later reuse, and perform all
 the tricks you expect from a regular Perl program.
 
+=head1 MASON 1 (HTML::MASON) VERSUS MASON 2 (MASON)
+
+Version 1 of Mason -- L<HTML::Mason|HTML::Mason> -- has been around since
+1998, is in wide use, and is very stable. However it has not changed much in
+years and is no longer actively developed.
+
+Version 2 of Mason -- L<Mason|Mason> -- was released in February of 2011.
+It is being very actively developed and has a much more modern
+architecture. If you are just starting out, we recommend you give Mason 2 a
+try.
+
+For a summary of differences between Mason 1 and 2 see
+
+    http://www.openswartz.com/2011/02/21/announcing-mason-2/
+
 =head1 INSTALLATION
 
 Mason has been tested under Linux, FreeBSD, Solaris, HPUX, and
