@@ -190,6 +190,7 @@ sub compile
     my $self = shift;
     my %p = validate( @_, { comp_source => { type => SCALAR|SCALARREF },
                             name => { type => SCALAR },
+                            comp_path => { type => SCALAR },
                             fh => { type => HANDLE, optional => 1 },
                           } );
     my $src = ref($p{comp_source}) ? $p{comp_source} : \$p{comp_source};
@@ -203,6 +204,8 @@ sub compile
     # So we're re-entrant in subcomps
     local $self->{paused_compiles} = [];
 
+    local $self->{comp_path} = $p{comp_path};
+
     # Preprocess the source.  The preprocessor routine is handed a
     # reference to the entire source.
     if ($self->preprocess)
@@ -222,7 +225,6 @@ sub start_component
     my $c = $self->{current_compile};
 
     $c->{in_main} = 1;
-    $c->{comp_with_content_stack} = [];
 
     $c->{in_block} = undef;
 
@@ -246,6 +248,8 @@ sub _init_comp_data
     $data->{flags} = {};
     $data->{attr} = {};
 
+    $data->{comp_with_content_stack} = [];
+
     foreach ( qw( cleanup filter init once shared ) )
     {
         $data->{blocks}{$_} = [];
@@ -258,7 +262,7 @@ sub end_component
     my $c = $self->{current_compile};
 
     $self->lexer->throw_syntax_error("Not enough component-with-content ending tags found")
-        if $c->{comp_with_content_stack} && @{ $c->{comp_with_content_stack} };
+        if @{ $c->{comp_with_content_stack} };
 }
 
 sub start_block
@@ -291,11 +295,11 @@ sub raw_block
     return $self->$method(%p) if $self->can($method);
 
     my $comment = '';
-    if ( $self->lexer->line_number )
+    if ( $self->lexer->line_number && $self->use_source_line_numbers )
     {
         my $line = $self->lexer->line_number;
-        my $file = $self->lexer->name;
-        $comment = "#line $line $file\n" if $self->use_source_line_numbers;
+        my $file = $self->_escape_filename( $self->lexer->name );
+        $comment = qq{#line $line "$file"\n};
     }
 
     push @{ $self->{current_compile}{blocks}{ $p{block_type} } }, "$comment$p{block}";
@@ -498,9 +502,11 @@ sub substitution
     if ($self->enable_autoflush) {
         $code = "\$m->print( $text );\n";
     } else {
-        # only output defined bits, which is what $m->print does
-        # internally as well
-        $code = "for ( grep { defined } $text ) { \$\$_outbuf .= \$_ }\n";
+        # more efficient output form when autoflush is disabled. only
+        # output defined bits, which is what $m->print does internally
+        # as well. use 'if defined' for maximum efficiency; grep
+        # creates a list.
+        $code = "for ( $text ) { \$\$_outbuf .= \$_ if defined }\n";
     }
 
     eval { $self->postprocess_perl->(\$code) } if $self->postprocess_perl;
@@ -622,16 +628,27 @@ sub _add_body_code
     # can break certain constructs like qw() list that spans multiple
     # perl-lines.
     if ( $self->lexer->line_number &&
-         $self->{current_compile}{last_body_code_type} ne 'perl_line' )
+         $self->{current_compile}{last_body_code_type} ne 'perl_line' &&
+         $self->use_source_line_numbers )
     {
         my $line = $self->lexer->line_number;
-        my $file = $self->lexer->name;
-        $self->{current_compile}{body} .= "#line $line $file\n" if $self->use_source_line_numbers;
+        my $file = $self->_escape_filename( $self->lexer->name );
+        $self->{current_compile}{body} .= qq{#line $line "$file"\n};
     }
 
     $self->{current_compile}{body} .= $_ foreach @_;
 }
 
+sub _escape_filename
+{
+    my $self = shift;
+    my $file = shift;
+
+    $file =~ s/\"//g;
+
+    return $file;
+}
+
 sub dump
 {
     my $self = shift;
@@ -810,9 +827,33 @@ a Compiler subclass needs to implement.
 
 =over 4
 
-=item compile(comp_source => <string>, name => <string>, comp_class => <string>)
+=item compile(...)
 
-The "comp_class" parameter may be ignored by the compiler.
+This method has several parameters:
+
+=over 8
+
+=item * comp_source (required)
+
+Either a scalar or reference to a scalar containing the component source.
+
+=item * name (required)
+
+The name of the component. This should be the filename of the
+component if it is file-based, or some other clear identifier of the
+component source.
+
+=item * comp_path (required)
+
+This should be the component's path.
+
+=item * fh (optional)
+
+If this is given then the output of the compiler will be sent directly
+to this handle, rather than being buffered in memory. This is an
+optimization to avoid memory usage.
+
+=back
 
 =item object_id
 
