@@ -1,10 +1,11 @@
-# Copyright (c) 1998-2002 by Jonathan Swartz. All rights reserved.
+# Copyright (c) 1998-2005 by Jonathan Swartz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
 package HTML::Mason::ComponentSource;
 
 use strict;
+use warnings;
 use File::Basename;
 use File::Spec;
 use HTML::Mason::Exceptions( abbr => [qw(param_error error)] );
@@ -74,7 +75,9 @@ sub object_code
 
     return $p{compiler}->compile( comp_source => $self->comp_source,
 				  name => $self->friendly_name,
-				  comp_class => $self->comp_class );
+                                  comp_path => $self->comp_path,
+				  comp_class => $self->comp_class,
+                                );
 }
 
 1;
