@@ -450,7 +450,7 @@ sub match_comp_content_call_end
 {
     my $self = shift;
 
-    if ( $self->{current}{comp_source} =~ m,\G</&(.*?)>,gc )
+    if ( $self->{current}{comp_source} =~ m,\G</&(.*?)>,gcs )
     {
         my $call = $1 || '';
         $self->{current}{compiler}->component_content_call_end( call_end => $call );
