@@ -17,11 +17,11 @@ sub import
 
     if ($p{read_only})
     {
-	foreach my $ro ( ref $p{read_only} ? @{ $p{read_only} } : $p{read_only} )
-	{
-	    no strict 'refs';
-	    *{"$caller\::$ro"} = sub { return $_[0]->{$ro} };
-	}
+        foreach my $ro ( ref $p{read_only} ? @{ $p{read_only} } : $p{read_only} )
+        {
+            no strict 'refs';
+            *{"$caller\::$ro"} = sub { return $_[0]->{$ro} };
+        }
     }
 
     #
@@ -32,72 +32,77 @@ sub import
     #
     if ($p{read_write})
     {
-	foreach my $rw ( ref $p{read_write} ? @{ $p{read_write} } : $p{read_write} )
-	{
-	    if (ref $rw)
-	    {
-		my ($name, $spec) = @$rw;
-		no strict 'refs';
-		*{"$caller\::$name"} =
-		    sub { if (@_ > 1)
-			  {
+        foreach my $rw ( ref $p{read_write} ? @{ $p{read_write} } : $p{read_write} )
+        {
+            if (ref $rw)
+            {
+                my ($name, $spec) = @$rw;
+                my $sub =
+                    sub { if (@_ > 1)
+                          {
                               my $s = shift;
-			      validate_pos(@_, $spec);
-			      $s->{$name} = shift;
+                              validate_pos(@_, $spec);
+                              $s->{$name} = shift;
                               return $s->{$name};
-			  }
-			  return $_[0]->{$name};
-		        };
-	    }
-	    else
-	    {
-		no strict 'refs';
-		*{"$caller\::$rw"} =
+                          }
+                          return $_[0]->{$name};
+                        };
+                no strict 'refs';
+                *{"$caller\::$name"} = $sub
+            }
+            else
+            {
+                my $sub =
                     sub { if (@_ > 1)
                           {
                               $_[0]->{$rw} = $_[1];
                           }
                           return $_[0]->{$rw};
                         };
-	    }
-	}
+                no strict 'refs';
+                *{"$caller\::$rw"} = $sub;
+            }
+        }
     }
 
     if ($p{read_write_contained})
     {
-	foreach my $object (keys %{ $p{read_write_contained} })
-	{
-	    foreach my $rwc (@{ $p{read_write_contained}{$object} })
-	    {
-		if (ref $rwc)
-		{
-		    my ($name, $spec) = @$rwc;
-		    no strict 'refs';
-		    *{"$caller\::$name"} =
-			sub { my $s = shift;
-			      my %new;
-			      if (@_)
-			      {
-				  validate_pos(@_, $spec);
-				  %new = ( $name => $_[0] );
-			      }
-			      my %args = $s->delayed_object_params( $object,
-								    %new );
-			      return $args{$rwc};
-			  };
-		}
-		else
-		{
-		    no strict 'refs';
-		    *{"$caller\::$rwc"} = sub { my $s = shift;
-						my %new = @_ ? ( $rwc => $_[0] ) : ();
-						my %args = $s->delayed_object_params( $object,
-										      %new );
-						return $args{$rwc};
-					    };
-		}
-	    }
-	}
+        foreach my $object (keys %{ $p{read_write_contained} })
+        {
+            foreach my $rwc (@{ $p{read_write_contained}{$object} })
+            {
+                if (ref $rwc)
+                {
+                    my ($name, $spec) = @$rwc;
+                    my $sub =
+                        sub { my $s = shift;
+                              my %new;
+                              if (@_)
+                              {
+                                  validate_pos(@_, $spec);
+                                  %new = ( $name => $_[0] );
+                              }
+                              my %args = $s->delayed_object_params( $object,
+                                                                    %new );
+                              return $args{$rwc};
+                            };
+                    no strict 'refs';
+                    *{"$caller\::$name"} = $sub;
+                }
+                else
+                {
+                    my $sub =
+                        sub { my $s = shift;
+                              my %new = @_ ? ( $rwc => $_[0] ) : ();
+                              my %args = $s->delayed_object_params( $object,
+                                                                    %new );
+                              return $args{$rwc};
+                            };
+                    no strict 'refs';
+                    *{"$caller\::$rwc"} = $sub;
+                }
+            }
+        }
     }
 }
 
