@@ -40,6 +40,7 @@ use HTML::Mason::Cache::BaseCache;
 use HTML::Mason::Plugin::Context;
 use HTML::Mason::Tools qw(can_weaken read_file compress_path load_pkg pkg_loaded absolute_comp_path);
 use HTML::Mason::Utils;
+use Log::Any qw($log);
 use Class::Container;
 use base qw(Class::Container);
 
@@ -241,6 +242,8 @@ sub _initialize {
         if (!ref($request_comp)) {
             $request_comp =~ s{/+}{/}g;
             $self->{top_path} = $path = $request_comp;
+            $log->debugf("top path is '%s'", $self->{top_path})
+                if $log->is_debug;
 
             my $retry_count = 0;
             search: {
@@ -253,6 +256,8 @@ sub _initialize {
                     if ( $request_comp = $self->interp->find_comp_upwards($path, $self->dhandler_name) ) {
                         my $parent_path = $request_comp->dir_path;
                         ($self->{dhandler_arg} = $self->{top_path}) =~ s{^$parent_path/?}{};
+                        $log->debugf("found dhandler '%s', dhandler_arg '%s'", $parent_path, $self->{dhandler_arg})
+                            if $log->is_debug;
                     }
                 }
 
@@ -306,7 +311,7 @@ sub _initialize {
                     #
                     {
                         no strict 'refs';
-                        unless (defined(%{$plugin . "::"})) {
+                        unless (keys %{$plugin . "::"}) {
                             eval "use $plugin;";
                             die $@ if $@;
                         }
@@ -422,6 +427,9 @@ sub exec {
     $self->{request_buffer} = $self->interp->preallocated_output_buffer;
     $self->{request_buffer} = '';
 
+    $log->debugf("starting request for '%s'", $self->request_comp->title)
+        if $log->is_debug;
+
     eval {
         # Build wrapper chain and index.
         my $request_comp = $self->request_comp;
@@ -498,6 +506,9 @@ sub exec {
         }
     };
 
+    $log->debugf("finishing request for '%s'", $self->request_comp->title)
+        if $log->is_debug;
+
     # Purge code cache if necessary.
     $self->interp->purge_code_cache;
 
@@ -668,8 +679,9 @@ sub cache
         if (!exists($options{namespace})) {
             $options{namespace} = $self->current_comp->comp_id;
         }
-        if (!exists($options{driver})) {
+        if (!exists($options{driver}) && !exists($options{driver_class})) {
             $options{driver} = $self->interp->cache_dir ? 'File' : 'Memory';
+            $options{global} = 1 if $options{driver} eq 'Memory';            
         }
         $options{root_dir} ||= $self->interp->cache_dir;
         return $chi_root_class->new(%options);
@@ -1207,6 +1219,7 @@ sub print
 #
 sub comp {
     my $self = shift;
+    my $log_is_debug = $log->is_debug;
 
     # Get modifiers: optional hash reference passed in as first argument.
     # Merge multiple hash references to simplify user and internal usage.
@@ -1233,6 +1246,11 @@ sub comp {
     error "$depth levels deep in component stack (infinite recursive call?)\n"
         if $depth >= $self->{max_recurse};
 
+    # Log start of component call.
+    #
+    $log->debugf("entering component '%s' [depth %d]", $comp->title(), $depth)
+        if $log_is_debug;
+
     # Keep the same output buffer unless store modifier was passed. If we have
     # a filter, put the filter buffer on the stack instead of the regular buffer.
     #
@@ -1318,6 +1336,11 @@ sub comp {
     # they don't get cleaned up until the component exits.
     pop @{ $self->{stack} };
 
+    # Log end of component call.
+    #
+    $log->debug(sprintf("exiting component '%s' [depth %d]", $comp->title(), $depth))
+        if $log_is_debug;
+
     # Repropagate error if one occurred, otherwise return result.
     rethrow_exception $error if $error;
     return $wantarray ? @result : $result[0];
@@ -1429,15 +1452,6 @@ sub request_args
 *top_args = \&request_args;
 *top_comp = \&request_comp;
 
-# deprecated in 1.1x
-sub time
-{
-    my ($self) = @_;
-    my $time = $self->interp->current_time;
-    $time = time() if $time eq 'real';
-    return $time;
-}
-
 #
 # Subroutine called by every component while in debug mode, convenient
 # for breakpointing.
@@ -1527,6 +1541,12 @@ sub _compute_base_comp_for_frame {
     return $frame->[STACK_BASE_COMP];
 }
 
+sub log
+{
+    my ($self) = @_;
+    return $self->current_comp->logger();
+}
+
 package Tie::Handle::Mason;
 
 sub TIEHANDLE
@@ -2313,6 +2333,14 @@ relative to the current component.
 
 See the L<subrequests|HTML::Mason::Devel/subrequests> section of the developer's manual for more information about subrequests.
 
+=item log
+
+=for html <a name="item_log"></a>
+
+Returns a C<Log::Any> logger with a log category specific to the
+current component.  The category for a component "/foo/bar" would be
+"HTML::Mason::Component::foo::bar".
+
 =item notes (key, value)
 
 =for html <a name="notes"></a>
